@@ -9,7 +9,6 @@ options(echo = T,width=65, digits=5, height=9999)
 postscript(file="ch07.ps", width=8, height=6, pointsize=9)
 options(contrasts = c("contr.treatment", "contr.poly"))
 
-data(anorexia)
 ax.1 <- glm(Postwt ~ Prewt + Treat + offset(Prewt),
             family = gaussian, data = anorexia)
 summary(ax.1)
@@ -48,7 +47,6 @@ dose.p(update(budworm.lg0, family = binomial(link = probit)),
        cf = c(1, 3), p = 1:3/4)
 
 options(contrasts = c("contr.treatment", "contr.poly"))
-data(birthwt)
 attach(birthwt)
 race <- factor(race, labels = c("white", "black", "other"))
 table(ptl)
@@ -77,7 +75,7 @@ attach(bwt)
 age1 <- age*(ftv=="1"); age2 <- age*(ftv=="2+")
 (birthwt.gam <- gam(low ~ s(age) + s(lwt) + smoke + ptd +
     ht + ui + ftv + s(age1) + s(age2) + smoke:ui, binomial, bwt))
-table(low, predict(birthwt.gam, bwt) > 0)
+table(low, predict(birthwt.gam) > 0)
 par(mfrow = c(2, 2))
 plot(birthwt.gam, se = TRUE)
 par(mfrow = c(1, 1))
@@ -85,7 +83,6 @@ detach()
 
 # 7.3  Poisson models
 
-data(housing)
 names(housing)
 house.glm0 <- glm(Freq ~ Infl*Type*Cont + Sat,
                   family = poisson, data = housing)
@@ -146,7 +143,6 @@ house.plr2$anova
 
 # 7.4  A negative binomial family
 
-data(quine)
 glm(Days ~ .^4, family = poisson, data = quine)
 quine.nb <- glm(Days ~ .^4, family = negative.binomial(2), data = quine)
 quine.nb0 <- update(quine.nb, . ~ Sex/(Age + Eth*Lrn))
